custom_chewie/src/material/progress_bar library

Classes

ProgressBar
ProgressBar is like Slider in Flutter SDK. ProgressBar support cacheValue which can be used to show the player's cached buffer. The colors is used to make colorful painter to draw the line and circle.
ProgressBarColors
Colors for the ProgressBar