DanmakuData class
Properties
-
color
↔ String?
-
optional color of the danmaku
Syntax: 0xFFFFFFF
getter/setter pair
-
content
↔ String
-
content of the danmaku
getter/setter pair
-
createdAt
↔ int?
-
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
↔ int?
-
optional unique id of danmaku and corresponding create/update time,
They are usually generated by database
getter/setter pair
-
position
↔ int
-
the display position on the screen.
position == 1, top; position == 2, bottom
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
time
↔ int
-
Time in milliseconds that the danmaku was sent in the video
getter/setter pair
-
updatedAt
↔ int?
-
getter/setter pair
-
userToken
↔ String?
-
optional Used to identify which user send this danmaku
getter/setter pair
-
videoId
↔ int?
-
optional Used to identify which video this danmaku was send
getter/setter pair